==> openshift-model-operator-5.1.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConsoleProvidersFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ConsoleProvidersFluentImpl<A extends ConsoleProvidersFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ConsoleProvidersFluent<A> {

    private StatuspageProviderBuilder statuspage;

    public ConsoleProvidersFluentImpl() {
    }

    public ConsoleProvidersFluentImpl(ConsoleProviders instance) {
        this.withStatuspage(instance.getStatuspage()); 
    }

    
/**
 * This method has been deprecated, please use method buildStatuspage instead.
 * @return The buildable object.
 */
@Deprecated public StatuspageProvider getStatuspage() {
        return this.statuspage!=null?this.statuspage.build():null;
    }

    public StatuspageProvider buildStatuspage() {
        return this.statuspage!=null?this.statuspage.build():null;
    }

    public A withStatuspage(StatuspageProvider statuspage) {
        _visitables.get("statuspage").remove(this.statuspage);
        if (statuspage!=null){ this.statuspage= new StatuspageProviderBuilder(statuspage); _visitables.get("statuspage").add(this.statuspage);} return (A) this;
    }

    public Boolean hasStatuspage() {
        return this.statuspage != null;
    }

    public A withNewStatuspage(String pageID) {
        return (A)withStatuspage(new StatuspageProvider(pageID));
    }

    public ConsoleProvidersFluent.StatuspageNested<A> withNewStatuspage() {
        return new StatuspageNestedImpl();
    }

    public ConsoleProvidersFluent.StatuspageNested<A> withNewStatuspageLike(StatuspageProvider item) {
        return new StatuspageNestedImpl(item);
    }

    public ConsoleProvidersFluent.StatuspageNested<A> editStatuspage() {
        return withNewStatuspageLike(getStatuspage());
    }

    public ConsoleProvidersFluent.StatuspageNested<A> editOrNewStatuspage() {
        return withNewStatuspageLike(getStatuspage() != null ? getStatuspage(): new StatuspageProviderBuilder().build());
    }

    public ConsoleProvidersFluent.StatuspageNested<A> editOrNewStatuspageLike(StatuspageProvider item) {
        return withNewStatuspageLike(getStatuspage() != null ? getStatuspage(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ConsoleProvidersFluentImpl that = (ConsoleProvidersFluentImpl) o;
        if (statuspage != null ? !statuspage.equals(that.statuspage) :that.statuspage != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(statuspage,  super.hashCode());
    }

    public class StatuspageNestedImpl<N> extends StatuspageProviderFluentImpl<ConsoleProvidersFluent.StatuspageNested<N>> implements ConsoleProvidersFluent.StatuspageNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final StatuspageProviderBuilder builder;

            StatuspageNestedImpl(StatuspageProvider item) {
                this.builder = new StatuspageProviderBuilder(this, item);
                        
            }

            StatuspageNestedImpl() {
                this.builder = new StatuspageProviderBuilder(this);
                        
            }

            public N and() {
                return (N) ConsoleProvidersFluentImpl.this.withStatuspage(builder.build());
            }

            public N endStatuspage() {
                return and();
            }
    }


}

==> openshift-model-operator-5.3.1-sources.jar: io/fabric8/openshift/api/model/operator/v1/ConsoleProvidersFluentImpl.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

public class ConsoleProvidersFluentImpl<A extends ConsoleProvidersFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ConsoleProvidersFluent<A> {

    private StatuspageProviderBuilder statuspage;

    public ConsoleProvidersFluentImpl() {
    }

    public ConsoleProvidersFluentImpl(ConsoleProviders instance) {
        this.withStatuspage(instance.getStatuspage()); 
    }

    
/**
 * This method has been deprecated, please use method buildStatuspage instead.
 * @return The buildable object.
 */
@Deprecated public StatuspageProvider getStatuspage() {
        return this.statuspage!=null?this.statuspage.build():null;
    }

    public StatuspageProvider buildStatuspage() {
        return this.statuspage!=null?this.statuspage.build():null;
    }

    public A withStatuspage(StatuspageProvider statuspage) {
        _visitables.get("statuspage").remove(this.statuspage);
        if (statuspage!=null){ this.statuspage= new StatuspageProviderBuilder(statuspage); _visitables.get("statuspage").add(this.statuspage);} return (A) this;
    }

    public Boolean hasStatuspage() {
        return this.statuspage != null;
    }

    public A withNewStatuspage(String pageID) {
        return (A)withStatuspage(new StatuspageProvider(pageID));
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> withNewStatuspage() {
        return new StatuspageNestedImpl();
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> withNewStatuspageLike(StatuspageProvider item) {
        return new StatuspageNestedImpl(item);
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editStatuspage() {
        return withNewStatuspageLike(getStatuspage());
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editOrNewStatuspage() {
        return withNewStatuspageLike(getStatuspage() != null ? getStatuspage(): new StatuspageProviderBuilder().build());
    }

    public io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<A> editOrNewStatuspageLike(StatuspageProvider item) {
        return withNewStatuspageLike(getStatuspage() != null ? getStatuspage(): item);
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ConsoleProvidersFluentImpl that = (ConsoleProvidersFluentImpl) o;
        if (statuspage != null ? !statuspage.equals(that.statuspage) :that.statuspage != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(statuspage,  super.hashCode());
    }

    public class StatuspageNestedImpl<N> extends StatuspageProviderFluentImpl<io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<N>> implements io.fabric8.openshift.api.model.operator.v1.ConsoleProvidersFluent.StatuspageNested<N>,io.fabric8.kubernetes.api.builder.Nested<N> {
        private final StatuspageProviderBuilder builder;

            StatuspageNestedImpl(StatuspageProvider item) {
                this.builder = new StatuspageProviderBuilder(this, item);
                        
            }

            StatuspageNestedImpl() {
                this.builder = new StatuspageProviderBuilder(this);
                        
            }

            public N and() {
                return (N) ConsoleProvidersFluentImpl.this.withStatuspage(builder.build());
            }

            public N endStatuspage() {
                return and();
            }
    }


}
